==> vala-0.3.2.tar.gz: vala-0.3.2/ccode/valaccodenewline.c <==
/* valaccodenewline.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <ccode/valaccodenewline.h>




enum  {
	VALA_CCODE_NEWLINE_DUMMY_PROPERTY
};
static void vala_ccode_newline_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
static gpointer vala_ccode_newline_parent_class = NULL;



static void vala_ccode_newline_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
	ValaCCodeNewline * self;
	self = VALA_CCODE_NEWLINE (base);
	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
	vala_ccode_writer_write_newline (writer);
}


/**
 * Represents a line break in the C code.
 */
ValaCCodeNewline* vala_ccode_newline_new (void) {
	ValaCCodeNewline * self;
	self = g_object_newv (VALA_TYPE_CCODE_NEWLINE, 0, NULL);
	return self;
}


static void vala_ccode_newline_class_init (ValaCCodeNewlineClass * klass) {
	vala_ccode_newline_parent_class = g_type_class_peek_parent (klass);
	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_newline_real_write;
}


static void vala_ccode_newline_init (ValaCCodeNewline * self) {
}


GType vala_ccode_newline_get_type (void) {
	static GType vala_ccode_newline_type_id = 0;
	if (G_UNLIKELY (vala_ccode_newline_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeNewlineClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_newline_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeNewline), 0, (GInstanceInitFunc) vala_ccode_newline_init };
		vala_ccode_newline_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeNewline", &g_define_type_info, 0);
	}
	return vala_ccode_newline_type_id;
}

==> vala-0.3.5.tar.gz: vala-0.3.5/ccode/valaccodenewline.c <==
/* valaccodenewline.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <ccode/valaccodenewline.h>




enum  {
	VALA_CCODE_NEWLINE_DUMMY_PROPERTY
};
static void vala_ccode_newline_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
static gpointer vala_ccode_newline_parent_class = NULL;



static void vala_ccode_newline_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
	ValaCCodeNewline * self;
	self = VALA_CCODE_NEWLINE (base);
	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
	vala_ccode_writer_write_newline (writer);
}


/**
 * Represents a line break in the C code.
 */
ValaCCodeNewline* vala_ccode_newline_new (void) {
	ValaCCodeNewline * self;
	self = g_object_newv (VALA_TYPE_CCODE_NEWLINE, 0, NULL);
	return self;
}


static void vala_ccode_newline_class_init (ValaCCodeNewlineClass * klass) {
	vala_ccode_newline_parent_class = g_type_class_peek_parent (klass);
	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_newline_real_write;
}


static void vala_ccode_newline_instance_init (ValaCCodeNewline * self) {
}


GType vala_ccode_newline_get_type (void) {
	static GType vala_ccode_newline_type_id = 0;
	if (vala_ccode_newline_type_id == 0) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeNewlineClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_newline_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeNewline), 0, (GInstanceInitFunc) vala_ccode_newline_instance_init };
		vala_ccode_newline_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeNewline", &g_define_type_info, 0);
	}
	return vala_ccode_newline_type_id;
}
